@@ -1,4 +1,4 @@
-#!/usr/pkg/bin/python3.12 -i
+#!/usr/pkg/bin/python3.13 -i
 #
 # Copyright 2013-2025 The Khronos Group Inc.
 #
@@ -10,7 +10,7 @@ import re
 from generator import (GeneratorOptions,
                        MissingGeneratorOptionsConventionsError,
                        MissingGeneratorOptionsError, MissingRegistryError,
-                       OutputGenerator, noneStr, regSortFeatures, write)
+                       OutputGenerator, noneStr, write)
 
 class CGeneratorOptions(GeneratorOptions):
     """CGeneratorOptions - subclass of GeneratorOptions.
